@@ -1,7 +1,6 @@
 package Catmandu::Importer::SRU::Parser::mabxml;
 
-#ABSTRACT: Package transforms SRU responses into Catmandu MAB2
-our $VERSION = '0.07'; #VERSION
+our $VERSION = '0.13';
 
 use Moo;
 use MAB2::Parser::XML;
@@ -28,10 +27,6 @@ __END__
 
 Catmandu::Importer::SRU::Parser::mabxml - Package transforms SRU responses into Catmandu MAB2
 
-=head1 VERSION
-
-version 0.07
-
 =head1 SYNOPSIS
 
     my %attrs = (
@@ -50,7 +45,7 @@ L<Catmandu::Importer::PICA>
 
 =head1 AUTHOR
 
-Johann Rolschewski <rolschewski@gmail.com>
+Johann Rolschewski <jorol@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
